<xsl:stylesheet xmlns="http://www.gekid.de/namespace" xmlns:aqua="http://www.aqua-institut.de" xmlns:saxon="http://saxon.sf.net" xmlns:xalan="http://xml.apache.org/xalan" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="xs xsi aqua saxon xalan #default" version="2.0" xpath-default-namespace="urn:gba:sqg">
	<xsl:output encoding="UTF-8" indent="yes" method="xml"/>
	<xsl:output omit-xml-declaration="yes" indent="yes"/>
	<xsl:strip-space elements="*"/>
	<xsl:template match="/">
		<xsl:variable name="schema_version" select="/root/header/document/software/specification/@Schema_Version"/>
		<ADT_GEKID Schema_Version="{$schema_version}">
			<xsl:variable name="root" select="/"/>
			<xsl:apply-templates mode="absender" select="(//felder[Absender_ID/@V])[1]">
				<xsl:with-param name="cases" select=".//header"/>
			</xsl:apply-templates>
			<!-- ####### Menge Patient  ####### -->
			<Menge_Patient>
				<xsl:variable name="patient_ids" select="distinct-values(//felder/Patient_ID/@V)"/>
				<xsl:for-each select="$patient_ids">
					<xsl:variable name="patient_id" select="."/>
					<Patient>
						<Patienten_Stammdaten Patient_ID="{$patient_id}">
							<xsl:apply-templates select="($root//case[.//felder[Patient_ID/@V = $patient_id]])[1]" mode="patient_stammdaten"/>
						</Patienten_Stammdaten>
						<!-- ####### Menge MELDUNG  ####### -->
						<Menge_Meldung>
						<xsl:variable name="meldung_ids" select="distinct-values($root//felder[Patient_ID/@V = $patient_id]/..//MELDUNG//felder/Meldung_ID/@V)"/>
						<xsl:for-each select="$meldung_ids">
						<xsl:variable name="meldung_id" select="."/>
							<xsl:call-template name="meldung">
								<xsl:with-param name="cases" select="$root//MELDUNG[felder[Meldung_ID/@V = $meldung_id]]"/>
							</xsl:call-template>
						</xsl:for-each>
					</Menge_Meldung>
					</Patient>
				</xsl:for-each>
			</Menge_Patient>
			<!-- ####### Menge Melder  ####### -->
			<Menge_Melder>
				<xsl:variable name="melder_ids" select="distinct-values($root//MELDUNG/felder/Melder_ID/@V)"/>
				<xsl:for-each select="$melder_ids">
					<xsl:variable name="melder_id" select="."/>
					<xsl:call-template name="melder">
						<xsl:with-param name="cases" select="$root//MELDUNG/felder[Melder_ID/@V = $melder_id]"/>
					</xsl:call-template>
				</xsl:for-each>
			</Menge_Melder>
		</ADT_GEKID>
	</xsl:template>
	<xsl:template match="case" mode="patient_stammdaten">
		<xsl:variable name="base" select="./qs_data/BASIS/felder"/>
		<xsl:copy-of select="aqua:fields($base, ('KrankenversichertenNr', 
			'KrankenkassenNr', 
			'Patienten_Nachname', 
			'Patienten_Titel', 
			'Patienten_Namenszusatz', 
			'Patienten_Vornamen', 
			'Patienten_Geburtsname'))"/>
		<!-- ####### Menge Frueherer Name  ####### -->
		<xsl:variable name="frueherer_name">
			<xsl:copy-of select="aqua:fields($base, ('Patienten_Frueherer_Name'))"/>
		</xsl:variable>
		<xsl:if test="$frueherer_name/*">
			<Menge_Frueherer_Name>
				<xsl:copy-of select="$frueherer_name"/>
			</Menge_Frueherer_Name>
		</xsl:if>
		<xsl:copy-of select="aqua:fields($base, (
			'Patienten_Geschlecht', 
			'Patienten_Geburtsdatum'))"/>
		<!-- ####### Menge Adresse  ####### -->
		<Menge_Adresse>
			<Adresse>
				<xsl:copy-of select="aqua:fields($base, ('Patienten_Strasse', 
					'Patienten_Hausnummer', 
					'Patienten_Land', 
					'Patienten_PLZ', 
					'Patienten_Ort'))"/>
			</Adresse>
		</Menge_Adresse>
	</xsl:template>	
	<xsl:template name="meldung">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases/felder"/>
		<xsl:variable name="meldung_id" select="$ref_fields/Meldung_ID/@V"/>
		<xsl:variable name="melder_id" select="$ref_fields/Melder_ID/@V"/>
		<xsl:variable name="modul_allgemein">
			<xsl:if test="exists($ref_fields/DatumSozialdienstkontakt_xxx_JNU/@V) or exists($ref_fields/DatumSozialdienstkontakt/@V)">
				<xsl:element name="DatumSozialdienstkontakt">
					<xsl:choose>
						<xsl:when test="$ref_fields/DatumSozialdienstkontakt_xxx_JNU/@V = 'J' and exists($ref_fields/DatumSozialdienstkontakt/@V)">
							<xsl:element name="Datum">
								<xsl:value-of select="aqua:endate($ref_fields/DatumSozialdienstkontakt/@V)"/>
							</xsl:element>
						</xsl:when>
						<xsl:when test="$ref_fields/DatumSozialdienstkontakt_xxx_JNU/@V = 'U' or $ref_fields/DatumSozialdienstkontakt_xxx_JNU/@V = 'N'">
							<xsl:element name="NU">
								<xsl:value-of select="$ref_fields/DatumSozialdienstkontakt_xxx_JNU/@V"/>
							</xsl:element>
						</xsl:when>
					</xsl:choose>
				</xsl:element>
			</xsl:if>
			<xsl:if test="exists($ref_fields/DatumStudienrekrutierung_xxx_JNU/@V) or exists($ref_fields/DatumStudienrekrutierung/@V)">
				<xsl:element name="DatumStudienrekrutierung">
					<xsl:choose>
						<xsl:when test="$ref_fields/DatumStudienrekrutierung_xxx_JNU/@V = 'J' and exists($ref_fields/DatumStudienrekrutierung/@V)">
							<xsl:element name="Datum">
								<xsl:value-of select="aqua:endate($ref_fields/DatumStudienrekrutierung/@V)"/>
							</xsl:element>
						</xsl:when>
						<xsl:when test="$ref_fields/DatumStudienrekrutierung_xxx_JNU/@V = 'U' or $ref_fields/DatumStudienrekrutierung_xxx_JNU/@V = 'N'">
							<xsl:element name="NU">
								<xsl:value-of select="$ref_fields/DatumStudienrekrutierung_xxx_JNU/@V"/>
							</xsl:element>
						</xsl:when>
					</xsl:choose>
				</xsl:element>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="primaertumor">
			<xsl:element name="Primaertumor_ICD_Code">
				<xsl:value-of select="$ref_fields/Primaertumor_ICD_Code/@V"/>
			</xsl:element>
			<xsl:element name="Primaertumor_ICD_Version">
				<xsl:value-of select="$ref_fields/Primaertumor_ICD_Version/@V"/>
			</xsl:element>
		</xsl:variable>
		<xsl:variable name="diagnosedatum">
			<xsl:if test="exists($ref_fields/Diagnosedatum_xxx_MELDUNG/@V)">
				<xsl:element name="Diagnosedatum">
					<xsl:value-of select="$ref_fields/Diagnosedatum_xxx_MELDUNG/@V"/>
				</xsl:element>
			</xsl:if>	
		</xsl:variable>
		<xsl:variable name="seitenlokalisation">
			<xsl:if test="exists($ref_fields/Seitenlokalisation/@V)">
				<xsl:element name="Seitenlokalisation">
					<xsl:value-of select="$ref_fields/Seitenlokalisation/@V"/>
				</xsl:element>
			</xsl:if>
		</xsl:variable>
		<Meldung Meldung_ID="{$meldung_id}" Melder_ID="{$melder_id}">
			<xsl:copy-of select="aqua:fields($ref_fields, ('Meldedatum', 'Meldebegruendung', 'Meldeanlass'))"/>
			<Tumorzuordnung Tumor_ID="{$ref_fields/Tumor_ID/@V}">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Primaertumor_ICD_Code', 
					'Primaertumor_ICD_Version', 
					'Diagnosedatum_xxx_MELDUNG', 
					'Seitenlokalisation'))"/>
			</Tumorzuordnung>
			<xsl:for-each select="$cases/bogen/DIAG">
				<xsl:call-template name="diagnose">
					<xsl:with-param name="cases" select="."/>
					<xsl:with-param name="primaertumor" select="$primaertumor"/>
					<xsl:with-param name="diagnosedatum" select="$diagnosedatum"/>
					<xsl:with-param name="seitenlokalisation" select="$seitenlokalisation"/>
					<xsl:with-param name="modul_allgemein" select="$modul_allgemein"/>
				</xsl:call-template>
			</xsl:for-each>
			<xsl:variable name="menge_op" select="$cases/bogen/OP"/>
			<xsl:variable name="menge_st" select="$cases/bogen/ST"/>
			<xsl:variable name="menge_syst" select="$cases/bogen/SYST"/>
			<xsl:variable name="menge_verlauf" select="$cases/bogen/VERLAUF"/>
			<xsl:variable name="menge_tumorkonferenz" select="$cases/bogen/TUMORKONF"/>
			<!-- Element OP -->
			<xsl:if test="$menge_op">
				<Menge_OP>
					<xsl:for-each select="$menge_op">
						<xsl:call-template name="op">
							<xsl:with-param name="cases" select="."/>
							<xsl:with-param name="modul_allgemein" select="$modul_allgemein"/>
						</xsl:call-template>
					</xsl:for-each>
				</Menge_OP>
			</xsl:if>
			<!-- Element ST -->
			<xsl:if test="$menge_st">
				<Menge_ST>
					<xsl:for-each select="$menge_st">
						<xsl:call-template name="st">
							<xsl:with-param name="cases" select="."/>
							<xsl:with-param name="modul_allgemein" select="$modul_allgemein"/>
						</xsl:call-template>
					</xsl:for-each>
				</Menge_ST>
			</xsl:if>
			<!-- Element SYST -->
			<xsl:if test="$menge_syst">
				<Menge_SYST>
					<xsl:for-each select="$menge_syst">
						<xsl:call-template name="syst">
							<xsl:with-param name="cases" select="."/>
							<xsl:with-param name="modul_allgemein" select="$modul_allgemein"/>
						</xsl:call-template>
					</xsl:for-each>
				</Menge_SYST>
			</xsl:if>
			<!-- Element VERLAUF -->
			<xsl:if test="$menge_verlauf">
				<Menge_Verlauf>
					<xsl:for-each select="$menge_verlauf">
						<xsl:call-template name="verlauf">
							<xsl:with-param name="cases" select="."/>
							<xsl:with-param name="modul_allgemein" select="$modul_allgemein"/>
						</xsl:call-template>
					</xsl:for-each>
				</Menge_Verlauf>
			</xsl:if>
			<!-- Element TUMORKONF -->
			<xsl:if test="$menge_tumorkonferenz">
				<Menge_Tumorkonferenz>
					<xsl:for-each select="$cases/bogen/TUMORKONF">
						<xsl:call-template name="tumorkonferenz">
							<xsl:with-param name="cases" select="."/>
						</xsl:call-template>
					</xsl:for-each>
				</Menge_Tumorkonferenz>
			</xsl:if>
		</Meldung>
	</xsl:template>
	<xsl:template name="diagnose">
		<xsl:param name="cases"/>
		<xsl:param name="primaertumor"/>
		<xsl:param name="diagnosedatum"/>
		<xsl:param name="seitenlokalisation"/>
		<xsl:param name="modul_allgemein"/>
		<xsl:variable name="ref_fields" select="$cases/felder"/>
		<Diagnose Tumor_ID="{$ref_fields/Tumor_ID/@V}">
			<!-- VARIABLEN -->
			<!-- Menge fruehere Tumorerkrankungen -->
			<xsl:variable name="menge_fruehere_tumorerkrankungen">
				<xsl:for-each select="$cases/bogen/DIAGFRUEHTUMOR">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="fruehere_tumorerkrankung">
						<xsl:copy-of select="aqua:fields($ref_fields, (
							'Freitext', 
							'ICD_Code', 
							'ICD_Version', 
							'Diagnosedatum_xxx_DIAG'))"/>
					</xsl:variable>
					<xsl:if test="$fruehere_tumorerkrankung/*">
						<Fruehere_Tumorerkrankung>
							<xsl:copy-of select="$fruehere_tumorerkrankung"/>
						</Fruehere_Tumorerkrankung>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- Menge Histologie -->
			<xsl:variable name="menge_histologie">
				<xsl:for-each select="$cases/bogen/DIAGHISTOLOGIE">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="histologie">
						<xsl:copy-of select="aqua:fields($ref_fields, ('Tumor_Histologiedatum_xxx_DIAG', 
							'Histologie_EinsendeNr_xxx_DIAG', 
							'ICD_Code', 
							'Morphologie_Code_xxx_DIAG',
							'Morphologie_ICD_O_Version_xxx_DIAG', 
							'Morphologie_Freitext_xxx_DIAG', 
							'Grading_xxx_DIAG', 
							'LK_untersucht_xxx_DIAG',
							'LK_befallen_xxx_DIAG', 
							'Sentinel_LK_untersucht_xxx_DIAG', 
							'Sentinel_LK_befallen_xxx_DIAG'))"/>
					</xsl:variable>
					<xsl:if test="$histologie/*">
						<Histologie>
							<xsl:copy-of select="$histologie"/>
						</Histologie>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- Menge Fernmetastasen -->
			<xsl:variable name="menge_fernmetastasen">
				<xsl:for-each select="$cases/bogen/DIAGFERNMETA">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="fm">
						<xsl:copy-of select="aqua:fields($ref_fields, ('FM_Diagnosedatum_xxx_DIAG', 'FM_Lokalisation_xxx_DIAG'))"/>
					</xsl:variable>
					<xsl:if test="$fm/*">
						<Fernmetastase>
							<xsl:copy-of select="$fm"/>
						</Fernmetastase>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- TNM klinisch -->
			<xsl:variable name="tnm_k">
				<xsl:copy-of select="aqua:fields($ref_fields, ('TNM_Datum_xxx_DIAG', 
					'TNM_Version_xxx_DIAG', 
					'TNM_y_Symbol_xxx_DIAG', 
					'TNM_r_Symbol_xxx_DIAG', 
					'TNM_a_Symbol_xxx_DIAG', 
					'TNM_c_p_u_Praefix_T_xxx_DIAG', 
					'TNM_T_xxx_DIAG', 
					'TNM_m_Symbol_xxx_DIAG', 
					'TNM_c_p_u_Praefix_N_xxx_DIAG', 
					'TNM_N_xxx_DIAG', 
					'TNM_c_p_u_Praefix_M_xxx_DIAG', 
					'TNM_M_xxx_DIAG', 
					'TNM_L_xxx_DIAG', 
					'TNM_V_xxx_DIAG', 
					'TNM_Pn_xxx_DIAG', 
					'TNM_S_xxx_DIAG'))"/>
			</xsl:variable>
			<!-- TNM pathologisch -->
			<xsl:variable name="tnm_p">
				<xsl:copy-of select="aqua:fields($ref_fields, ('TNM_Datum_xxx_DIAG_path', 
					'TNM_Version_xxx_DIAG_path', 
					'TNM_y_Symbol_xxx_DIAG_path', 
					'TNM_r_Symbol_xxx_DIAG_path', 
					'TNM_a_Symbol_xxx_DIAG_path', 
					'TNM_c_p_u_Praefix_T_xxx_DIAG_path', 
					'TNM_T_xxx_DIAG_path', 
					'TNM_m_Symbol_xxx_DIAG_path', 
					'TNM_c_p_u_Praefix_N_xxx_DIAG_path', 
					'TNM_N_xxx_DIAG_path', 
					'TNM_c_p_u_Praefix_M_xxx_DIAG_path', 
					'TNM_M_xxx_DIAG_path', 
					'TNM_L_xxx_DIAG_path', 
					'TNM_V_xxx_DIAG_path', 
					'TNM_Pn_xxx_DIAG_path', 
					'TNM_S_xxx_DIAG_path'))"/>
			</xsl:variable>
			<!-- Menge weitere Klassifikationen -->
			<xsl:variable name="menge_weitere_klassifikationen">
				<xsl:for-each select="$cases/bogen/DIAGWEITKLASS">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="weitere_klassifikation">
						<xsl:copy-of select="aqua:fields($ref_fields, ('Datum_xxx_DIAG', 
							'Name_xxx_DIAG', 
							'Name_sonstige_xxx_DIAG', 
							'Stadium_xxx_DIAG'))"/>
					</xsl:variable>
					<xsl:variable name="case_sonstige">
						<xsl:copy-of select="aqua:fields($ref_fields, ('Name_sonstige_xxx_DIAG'))"/>
					</xsl:variable>
					<xsl:if test="$weitere_klassifikation/*">
						<Weitere_Klassifikation>
							<xsl:copy-of select="aqua:fields($ref_fields, ('Datum_xxx_DIAG'))"/>
							<xsl:choose>
								<xsl:when test="$case_sonstige/*">
									<xsl:copy-of select="$case_sonstige"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="aqua:fields($ref_fields, ('Name_xxx_DIAG'))"/>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:copy-of select="aqua:fields($ref_fields, ('Stadium_xxx_DIAG'))"/>
						</Weitere_Klassifikation>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- Modul Mammakarzinom -->
			<xsl:variable name="modul_mamma">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Praetherapeutischer_Menopausenstatus', 
					'HormonrezeptorStatus_Oestrogen', 
					'HormonrezeptorStatus_Progesteron',
					'Her2neuStatus',
					'PraeopDrahtmarkierung', 
					'IntraopPraeparatkontrolle', 
					'TumorgroesseInvasiv', 
					'TumorgroesseDCIS'))"/>
			</xsl:variable>
			<!-- Modul kolorektales Karzinom -->
			<xsl:variable name="modul_darm">
				<xsl:copy-of select="aqua:fields($ref_fields,('RektumAbstandAnokutanlinie',
					'RektumAbstandAboralerResektionsrand', 
					'RektumAbstandCircResektionsebene', 
					'RektumQualitaetTME',
					'RektumMRTDuennschichtAngabemesorektaleFaszie', 
					'ArtEingriff', 
					'RektumAnzeichnungStomaposition', 
					'GradRektumAnastomoseninsuffizienz',
					'ASA', 
					'RASMutation'))"/>
			</xsl:variable>
			<!--Modul Prostatakrebs -->
			<xsl:variable name="modul_prostata">
				<xsl:variable name="gleason_score">
					<xsl:copy-of select="aqua:fields($ref_fields,('GleasonGradPrimaer_xxx_DIAG', 
						'GleasonGradSekundaer_xxx_DIAG', 
						'GleasonScoreErgebnis_xxx_DIAG'))"/>
				</xsl:variable>
				<xsl:if test="$gleason_score/*">
					<GleasonScore>
						<xsl:copy-of select="$gleason_score"/>
					</GleasonScore>
				</xsl:if>
				<xsl:copy-of select="aqua:fields($ref_fields,('AnlassGleasonScore_xxx_DIAG', 
					'DatumStanzen_xxx_DIAG', 
					'AnzahlStanzen_xxx_DIAG', 
					'AnzahlPosStanzen_xxx_DIAG'))"/>
				<xsl:variable name="ca_befall_prozent">
					<xsl:copy-of select="aqua:fields($ref_fields,('Prozentzahl_xxx_DIAG'))"/>
				</xsl:variable>
				<xsl:variable name="ca_befall_unbekannt">
					<xsl:copy-of select="aqua:fields($ref_fields,('U_xxx_DIAG'))"/>
				</xsl:variable>
				<xsl:if test="$ca_befall_prozent/* or ca_befall_unbekannt/*">
					<CaBefallStanze>
						<xsl:choose>
							<xsl:when test="$ca_befall_prozent/*">
								<xsl:copy-of select="$ca_befall_prozent"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="$ca_befall_unbekannt"/>
							</xsl:otherwise>
						</xsl:choose>
					</CaBefallStanze>
				</xsl:if>
				<xsl:copy-of select="aqua:fields($ref_fields,('PSA_xxx_DIAG', 
					'DatumPSA_xxx_DIAG', 
					'KomplPostOP_ClavienDindo_xxx_DIAG'))"/>
			</xsl:variable>
			<!--Modul Malignes Melanom -->
			<xsl:variable name="modul_malignes_melanom">
				<xsl:copy-of select="aqua:fields($ref_fields,('Sicherheitsabstand_Primaertumor_xxx_DIAG', 
					'Tumordicke_xxx_DIAG',
					'LDH_xxx_DIAG',
					'Ulzeration_xxx_DIAG'))"/>
			</xsl:variable>
			<!-- Primaertumor -->
			<xsl:if test="$primaertumor/*">
				<xsl:copy-of select="$primaertumor"/>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Primaertumor_Diagnosetext', 
				'Primaertumor_Topographie_ICD_O', 
				'Primaertumor_Topographie_ICD_O_Version', 
				'Primaertumor_Topographie_ICD_O_Freitext'))"/>
			<!-- Diagnosedatum -->
			<xsl:if test="$diagnosedatum/*">
				<xsl:copy-of select="$diagnosedatum"/>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Diagnosesicherung'))"/>
			<!-- Seitenlokalisation -->
			<xsl:if test="$seitenlokalisation/*">
				<xsl:copy-of select="$seitenlokalisation"/>
			</xsl:if>
			<!-- Menge fruehere Tumorerkrankungen -->
			<xsl:if test="$menge_fruehere_tumorerkrankungen/*">
				<Menge_Fruehere_Tumorerkrankung>
					<xsl:copy-of select="$menge_fruehere_tumorerkrankungen"/>
				</Menge_Fruehere_Tumorerkrankung>
			</xsl:if>
			<!-- Menge Histologie -->
			<xsl:if test="$menge_histologie/*">
				<Menge_Histologie>
					<xsl:copy-of select="$menge_histologie"/>
				</Menge_Histologie>
			</xsl:if>
			<!-- Menge Fernmetastasen -->
			<xsl:if test="$menge_fernmetastasen/*">
				<Menge_FM>
					<xsl:copy-of select="$menge_fernmetastasen"/>
				</Menge_FM>
			</xsl:if>
			<!-- TNM klinisch -->
			<xsl:if test="$tnm_k/*">
				<cTNM>
					<xsl:copy-of select="$tnm_k"/>
				</cTNM>
			</xsl:if>
			<!-- TNM pathologisch -->
			<xsl:if test="$tnm_p/*">
				<pTNM>
					<xsl:copy-of select="$tnm_p"/>
				</pTNM>
			</xsl:if>
			<!-- Menge weitere Klassifikationen -->
			<xsl:if test="$menge_weitere_klassifikationen/*">
				<Menge_Weitere_Klassifikation>
					<xsl:copy-of select="$menge_weitere_klassifikationen"/>
				</Menge_Weitere_Klassifikation>
			</xsl:if>
			<!-- Modul Mammakarzinom -->
			<xsl:if test="$modul_mamma/*">
				<Modul_Mamma>
					<xsl:copy-of select="$modul_mamma"/>
				</Modul_Mamma>
			</xsl:if>
			<!-- Modul kolorektales Karzinom -->
			<xsl:if test="$modul_darm/*">
				<Modul_Darm>
					<xsl:copy-of select="$modul_darm"/>
				</Modul_Darm>
			</xsl:if>
			<!--Modul Prostatakrebs -->
			<xsl:if test="$modul_prostata/*">
				<Modul_Prostata>
					<xsl:copy-of select="$modul_prostata"/>
				</Modul_Prostata>
			</xsl:if>
			<!--Modul Malignes Melanom -->
			<xsl:if test="$modul_malignes_melanom/*">
				<Modul_Malignes_Melanom>
					<xsl:copy-of select="$modul_malignes_melanom"/>
				</Modul_Malignes_Melanom>
			</xsl:if>
			<!-- Modul Allgemein -->
			<xsl:if test="$modul_allgemein/*">
				<Modul_Allgemein>
					<xsl:copy-of select="$modul_allgemein"/>
				</Modul_Allgemein>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Allgemeiner_Leistungszustand_xxx_DIAG', 'Anmerkung_xxx_DIAG'))"/>
		</Diagnose>
	</xsl:template>
	<xsl:template name="op">
		<xsl:param name="cases"/>
		<xsl:param name="modul_allgemein"/>
		<xsl:variable name="ref_fields" select="$cases/felder"/>
		<OP OP_ID="{$ref_fields/OP_ID/@V}">
			<!-- VARIABLEN -->
			<!-- Menge OPS -->
			<xsl:variable name="menge_ops">
				<xsl:copy-of select="aqua:fields($ref_fields, ('OP_OPS'))"/>
			</xsl:variable>
			<!-- Histologie -->
			<xsl:variable name="hist">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Tumor_Histologiedatum_xxx_OP',
					'Histologie_EinsendeNr_xxx_OP',
					'Morphologie_Code_xxx_OP',
					'Morphologie_ICD_O_Version_xxx_OP',
					'Morphologie_Freitext_xxx_OP',
					'Grading_xxx_OP',
					'LK_untersucht_xxx_OP',
					'LK_befallen_xxx_OP',
					'Sentinel_LK_untersucht_xxx_OP',
					'Sentinel_LK_befallen_xxx_OP'))"/>
			</xsl:variable>
			<!-- TNM -->
			<xsl:variable name="tnm">
				<xsl:copy-of select="aqua:fields($ref_fields, ('TNM_Datum_xxx_OP',
					'TNM_Version_xxx_OP',
					'TNM_y_Symbol_xxx_OP',
					'TNM_r_Symbol_xxx_OP',
					'TNM_a_Symbol_xxx_OP',
					'TNM_c_p_u_Praefix_T_xxx_OP',
					'TNM_T_xxx_OP',
					'TNM_m_Symbol_xxx_OP',
					'TNM_c_p_u_Praefix_N_xxx_OP',
					'TNM_N_xxx_OP',
					'TNM_c_p_u_Praefix_M_xxx_OP',
					'TNM_M_xxx_OP',
					'TNM_L_xxx_OP',
					'TNM_V_xxx_OP',
					'TNM_Pn_xxx_OP',
					'TNM_S_xxx_OP'))"/>
			</xsl:variable>
			<!-- Residualstatus -->
			<xsl:variable name="residualstatus">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Lokale_Beurteilung_Residualstatus_xxx_OP', 'Gesamtbeurteilung_Residualstatus_xxx_OP'))"/>
			</xsl:variable>
			<!-- Menge Komplikationen -->
			<xsl:variable name="menge_komp">
				<xsl:copy-of select="aqua:fields($ref_fields, ('OP_Komplikation'))"/>
				<xsl:for-each select="$ref_fields/OP_Komplikationen/@V">
					<OP_Komplikation>
						<xsl:value-of select="."/>
					</OP_Komplikation>
				</xsl:for-each>
			</xsl:variable>
			<!-- Modul Mammakarzinom -->
			<xsl:variable name="modul_mamma">
				<xsl:copy-of select="aqua:fields($ref_fields, ('PraeopDrahtmarkierung', 'IntraopPraeparatkontroll', 'TumorgroesseInvasiv', 'TumorgroesseDCIS'))"/>
			</xsl:variable>
			<!-- Modul kolorektales Karzinom -->
			<xsl:variable name="modul_darm">
				<xsl:copy-of select="aqua:fields($ref_fields, ('RektumAbstandAboralerResektionsrand', 
					'RektumAbstandCircResektionsebene',
					'RektumQualitaetTME',
					'ArtEingriff',
					'RektumAnzeichnungStomaposition',
					'GradRektumAnastomoseninsuffizienz',
					'ASA'))"/>
			</xsl:variable>
			<!--Modul Prostatakrebs -->
			<xsl:variable name="modul_prostata">
				<xsl:variable name="gleason_score">
					<xsl:copy-of select="aqua:fields($ref_fields,('GleasonGradPrimaer_xxx_OP',
						'GleasonGradSekundaer_xxx_OP', 
						'GleasonScoreErgebnis_xxx_OP'))"/>
				</xsl:variable>
				<xsl:if test="$gleason_score/*">
					<GleasonScore>
						<xsl:copy-of select="$gleason_score"/>
					</GleasonScore>
				</xsl:if>
				<xsl:copy-of select="aqua:fields($ref_fields,('AnlassGleasonScore_xxx_OP',
					'DatumStanzen_xxx_OP',
					'AnzahlStanzen_xxx_OP',
					'AnzahlPosStanzen_xxx_OP'))"/>
				<xsl:variable name="ca_befall_prozent">
					<xsl:copy-of select="aqua:fields($ref_fields,('Prozentzahl_xxx_OP'))"/>
				</xsl:variable>
				<xsl:variable name="ca_befall_unbekannt">
					<xsl:copy-of select="aqua:fields($ref_fields,('U_xxx_OP'))"/>
				</xsl:variable>
				<xsl:if test="$ca_befall_prozent/* or ca_befall_unbekannt/*">
					<CaBefallStanze>
						<xsl:choose>
							<xsl:when test="$ca_befall_prozent/*">
								<xsl:copy-of select="$ca_befall_prozent"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="$ca_befall_unbekannt"/>
							</xsl:otherwise>
						</xsl:choose>
					</CaBefallStanze>
				</xsl:if>
				<xsl:copy-of select="aqua:fields($ref_fields,('PSA_xxx_OP',
					'DatumPSA_xxx_OP',
					'KomplPostOP_ClavienDindo_xxx_OP'))"/>
			</xsl:variable>
			<!--Modul Malignes Melanom -->
			<xsl:variable name="modul_malignes_melanom">
				<xsl:copy-of select="aqua:fields($ref_fields,('Sicherheitsabstand_Primaertumor_xxx_OP', 
					'Tumordicke_xxx_OP',
					'LDH_xxx_OP',
					'Ulzeration_xxx_OP'))"/>
			</xsl:variable>
			<!-- Menge Operateur -->
			<xsl:variable name="menge_operateur">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Name_Operateur'))"/>
			</xsl:variable>
			<!-- AUSGABE -->
			<xsl:copy-of select="aqua:fields($ref_fields, ('OP_Intention','OP_Datum'))"/>
			<xsl:if test="$menge_ops/*">
				<Menge_OPS>
					<xsl:copy-of select="$menge_ops"/>
				</Menge_OPS>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('OP_OPS_Version'))"/>
			<xsl:if test="$hist/*">
				<Histologie>
					<xsl:copy-of select="$hist"/>
				</Histologie>
			</xsl:if>
			<xsl:if test="$tnm/*">
				<TNM>
					<xsl:copy-of select="$tnm"/>
				</TNM>
			</xsl:if>
			<xsl:if test="$residualstatus/*">
				<Residualstatus>
					<xsl:copy-of select="$residualstatus"/>
				</Residualstatus>
			</xsl:if>
			<xsl:if test="$menge_komp/*">
				<Menge_Komplikation>
					<xsl:copy-of select="$menge_komp"/>
				</Menge_Komplikation>
			</xsl:if>
			<!-- Modul Mammakarzinom -->
			<xsl:if test="$modul_mamma/*">
				<Modul_Mamma>
					<xsl:copy-of select="$modul_mamma"/>
				</Modul_Mamma>
			</xsl:if>
			<!-- Modul kolorektales Karzinom -->
			<xsl:if test="$modul_darm/*">
				<Modul_Darm>
					<xsl:copy-of select="$modul_darm"/>
				</Modul_Darm>
			</xsl:if>
			<!--Modul Prostatakrebs -->
			<xsl:if test="$modul_prostata/*">
				<Modul_Prostata>
					<xsl:copy-of select="$modul_prostata"/>
				</Modul_Prostata>
			</xsl:if>
			<!--Modul Malignes Melanom -->
			<xsl:if test="$modul_malignes_melanom/*">
				<Modul_Malignes_Melanom>
					<xsl:copy-of select="$modul_malignes_melanom"/>
				</Modul_Malignes_Melanom>
			</xsl:if>
			<!-- Modul Allgemein -->
			<xsl:if test="$modul_allgemein/*">
				<Modul_Allgemein>
					<xsl:copy-of select="$modul_allgemein"/>
				</Modul_Allgemein>
			</xsl:if>
			<xsl:if test="$menge_operateur/*">
				<Menge_Operateur>
					<xsl:copy-of select="$menge_operateur"/>
				</Menge_Operateur>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung_xxx_OP'))"/>
		</OP>
	</xsl:template>
	<xsl:template name="st">
		<xsl:param name="cases"/>
		<xsl:param name="modul_allgemein"/>
		<xsl:variable name="ref_fields" select="$cases/felder"/>
		<ST ST_ID="{$ref_fields/ST_ID/@V}">
			<!-- VARIABLEN -->
			<!-- Menge Bestrahlung -->
			<xsl:variable name="menge_bestrahlung">
				<xsl:for-each select="$cases/bogen/STBESTRAHLUNG">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="bestrahlung">
						<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Zielgebiet',
							'ST_Seite_Zielgebiet',
							'ST_Beginn_Datum',
							'ST_Ende_Datum',
							'ST_Applikationsart'))"/>
						<!-- Workaround für Einzel- und Gesamtdosis / ST -->
						<xsl:variable name="lGesamtdosis">
							<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Gesamtdosis_xxx_ST','ST_Gesamtdosis_Einheit_xxx_ST'))"/>
						</xsl:variable>
						<xsl:variable name="lEinzeldosis">
							<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Einzeldosis_xxx_ST','ST_Einzeldosis_Einheit_xxx_ST'))"/>
						</xsl:variable>
						<xsl:if test="$lGesamtdosis/*">
							<ST_Gesamtdosis>
								<xsl:copy-of select="$lGesamtdosis"/>
							</ST_Gesamtdosis>
						</xsl:if>
						<xsl:if test="$lEinzeldosis/*">
							<ST_Einzeldosis>
								<xsl:copy-of select="$lEinzeldosis"/>
							</ST_Einzeldosis>
						</xsl:if>
					</xsl:variable>
					<xsl:if test="$bestrahlung/*">
						<Bestrahlung>
							<xsl:copy-of select="$bestrahlung"/>
						</Bestrahlung>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- Residualstatus -->
			<xsl:variable name="residualstatus">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Lokale_Beurteilung_Residualstatus_xxx_ST',
					'Gesamtbeurteilung_Residualstatus_xxx_ST'))"/>
			</xsl:variable>
			<!-- Menge Nebenwirkungen -->
			<xsl:variable name="menge_nebenwirkungen">
				<xsl:for-each select="$cases/bogen/STNEBENWIRKUNG">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="nebenwirkung">
						<xsl:copy-of select="aqua:fields($ref_fields, ('Nebenwirkung_Grad_xxx_ST',
							'Nebenwirkung_Art_xxx_ST',
							'Nebenwirkung_Version_xxx_ST'))"/>
					</xsl:variable>
					<xsl:if test="$nebenwirkung/*">
						<ST_Nebenwirkung>
							<xsl:copy-of select="$nebenwirkung"/>
						</ST_Nebenwirkung>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- AUSGABE -->
			<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Intention','ST_Stellung_OP'))"/>
			<!-- Menge Bestrahlung -->
			<xsl:if test="$menge_bestrahlung/*">
				<Menge_Bestrahlung>
					<xsl:copy-of select="$menge_bestrahlung"/>
				</Menge_Bestrahlung>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('ST_Ende_Grund'))"/>
			<!-- Residualstatus -->
			<xsl:if test="$residualstatus/*">
				<Residualstatus>
					<xsl:copy-of select="$residualstatus"/>
				</Residualstatus>
			</xsl:if>
			<!-- Menge Nebenwirkungen -->
			<xsl:if test="$menge_nebenwirkungen/*">
				<Menge_Nebenwirkung>
					<xsl:copy-of select="$menge_nebenwirkungen"/>
				</Menge_Nebenwirkung>
			</xsl:if>
			<!-- Modul Allgemein -->
			<xsl:if test="$modul_allgemein/*">
				<Modul_Allgemein>
					<xsl:copy-of select="$modul_allgemein"/>
				</Modul_Allgemein>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung_xxx_ST'))"/>
		</ST>
	</xsl:template>
	<xsl:template name="syst">
		<xsl:param name="cases"/>
		<xsl:param name="modul_allgemein"/>
		<xsl:variable name="ref_fields" select="$cases/felder"/>
		<SYST SYST_ID="{$ref_fields/SYST_ID/@V}">
			<!-- VARIABLEN -->
			<!-- Menge Therapieart -->
			<xsl:variable name="menge_therapieart">
				<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Therapieart'))"/>
			</xsl:variable>
			<!-- Menge Substanz -->
			<xsl:variable name="menge_substanz">
				<xsl:for-each select="$cases/bogen/SYSTSUBSTANZ">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Substanz'))"/>
				</xsl:for-each>
			</xsl:variable>
			<!-- Residualstatus -->
			<xsl:variable name="residualstatus">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Lokale_Beurteilung_Residualstatus_xxx_SYST', 'Gesamtbeurteilung_Residualstatus_xxx_SYST'))"/>
			</xsl:variable>
			<!-- Menge Nebenwirkungen -->
			<xsl:variable name="menge_nebenwirkungen">
				<xsl:for-each select="$cases/bogen/SYSTNEBENWIRKUNG">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="nebenwirkung">
						<xsl:copy-of select="aqua:fields($ref_fields, ('Nebenwirkung_Grad_xxx_SYST', 'Nebenwirkung_Art_xxx_SYST', 'Nebenwirkung_Version_xxx_SYST'))"/>
					</xsl:variable>
					<xsl:if test="$nebenwirkung/*">
						<SYST_Nebenwirkung>
							<xsl:copy-of select="$nebenwirkung"/>
						</SYST_Nebenwirkung>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- AUSGABE -->
			<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Intention', 'SYST_Stellung_OP'))"/>
			<!-- Menge Therapieart -->
			<xsl:if test="$menge_therapieart/*">
				<Menge_Therapieart>
					<xsl:copy-of select="$menge_therapieart"/>
				</Menge_Therapieart>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Therapieart_Anmerkung', 'SYST_Protokoll', 'SYST_Beginn_Datum'))"/>
			<!-- Menge Substanz -->
			<xsl:if test="$menge_substanz/*">
				<Menge_Substanz>
					<xsl:copy-of select="$menge_substanz"/>
				</Menge_Substanz>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('SYST_Ende_Grund', 'SYST_Ende_Datum'))"/>
			<!-- Residualstatus -->
			<xsl:if test="$residualstatus/*">
				<Residualstatus>
					<xsl:copy-of select="$residualstatus"/>
				</Residualstatus>
			</xsl:if>
			<!-- Menge Nebenwirkungen -->
			<xsl:if test="$menge_nebenwirkungen/*">
				<Menge_Nebenwirkung>
					<xsl:copy-of select="$menge_nebenwirkungen"/>
				</Menge_Nebenwirkung>
			</xsl:if>
			<!-- Modul Allgemein -->
			<xsl:if test="$modul_allgemein/*">
				<Modul_Allgemein>
					<xsl:copy-of select="$modul_allgemein"/>
				</Modul_Allgemein>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung_xxx_SYST'))"/>
		</SYST>
	</xsl:template>
	<xsl:template name="verlauf">
		<xsl:param name="cases"/>
		<xsl:param name="modul_allgemein"/>
		<xsl:variable name="ref_fields" select="$cases/felder"/>
		<Verlauf Verlauf_ID="{$ref_fields/Verlauf_ID/@V}">
			<!-- VARIABLEN -->
			<!-- Menge OPS -->
			<xsl:variable name="menge_ops">
				<xsl:copy-of select="aqua:fields($ref_fields, ('OP_OPS'))"/>
			</xsl:variable>
			<!-- Histologie -->
			<xsl:variable name="hist">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Tumor_Histologiedatum_xxx_VERLAUF',
					'Histologie_EinsendeNr_xxx_VERLAUF',
					'Morphologie_Code_xxx_VERLAUF',
					'Morphologie_ICD_O_Version_xxx_VERLAUF',
					'Morphologie_Freitext_xxx_VERLAUF',
					'Grading_xxx_VERLAUF',
					'LK_untersucht_xxx_VERLAUF',
					'LK_befallen_xxx_VERLAUF',
					'Sentinel_LK_untersucht_xxx_VERLAUF',
					'Sentinel_LK_befallen_xxx_VERLAUF'))"/>
			</xsl:variable>
			<!-- TNM -->
			<xsl:variable name="tnm">
				<xsl:copy-of select="aqua:fields($ref_fields, ('TNM_Datum_xxx_VERLAUF',
					'TNM_Version_xxx_VERLAUF',
					'TNM_y_Symbol_xxx_VERLAUF',
					'TNM_r_Symbol_xxx_VERLAUF',
					'TNM_a_Symbol_xxx_VERLAUF',
					'TNM_c_p_u_Praefix_T_xxx_VERLAUF',
					'TNM_T_xxx_VERLAUF',
					'TNM_m_Symbol_xxx_VERLAUF',
					'TNM_c_p_u_Praefix_N_xxx_VERLAUF',
					'TNM_N_xxx_VERLAUF',
					'TNM_c_p_u_Praefix_M_xxx_VERLAUF',
					'TNM_M_xxx_VERLAUF',
					'TNM_L_xxx_VERLAUF',
					'TNM_V_xxx_VERLAUF',
					'TNM_Pn_xxx_VERLAUF',
					'TNM_S_xxx_VERLAUF'))"/>
			</xsl:variable>
			<!-- Menge weitere Klassifikationen -->
			<xsl:variable name="menge_weitere_klassifikationen">
				<xsl:for-each select="$cases/bogen/VERLAUFWEITKLASS">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="weitere_klassifikation">
						<xsl:copy-of select="aqua:fields($ref_fields, ('Datum_xxx_VERLAUF', 'Name_xxx_VERLAUF', 'Name_sonstige_xxx_VERLAUF', 'Stadium_xxx_VERLAUF'))"/>
					</xsl:variable>
					<xsl:variable name="case_sonstige">
						<xsl:copy-of select="aqua:fields($ref_fields, ('Name_sonstige_xxx_VERLAUF'))"/>
					</xsl:variable>
					<xsl:if test="$weitere_klassifikation/*">
						<Weitere_Klassifikation>
							<xsl:copy-of select="aqua:fields($ref_fields, ('Datum_xxx_VERLAUF'))"/>
							<xsl:choose>
								<xsl:when test="$case_sonstige/*">
									<xsl:copy-of select="$case_sonstige"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="aqua:fields($ref_fields, ('Name_xxx_VERLAUF'))"/>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:copy-of select="aqua:fields($ref_fields, ('Stadium_xxx_VERLAUF'))"/>
						</Weitere_Klassifikation>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- Menge Fernmetastasen -->
			<xsl:variable name="menge_fernmetastasen">
				<xsl:for-each select="$cases/bogen/VERLAUFFERNMETA">
					<xsl:variable name="ref_fields" select="./felder"/>
					<xsl:variable name="fm">
						<xsl:copy-of select="aqua:fields($ref_fields, ('FM_Diagnosedatum_xxx_VERLAUF', 'FM_Lokalisation_xxx_VERLAUF'))"/>
					</xsl:variable>
					<xsl:if test="$fm/*">
						<Fernmetastase>
							<xsl:copy-of select="$fm"/>
						</Fernmetastase>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!--Modul Prostatakrebs -->
			<xsl:variable name="modul_prostata">
				<xsl:variable name="gleason_score">
					<xsl:copy-of select="aqua:fields($ref_fields,('GleasonGradPrimaer_xxx_VERLAUF', 'GleasonGradSekundaer_xxx_VERLAUF', 'GleasonScoreErgebnis_xxx_VERLAUF'))"/>
				</xsl:variable>
				<xsl:if test="$gleason_score/*">
					<GleasonScore>
						<xsl:copy-of select="$gleason_score"/>
					</GleasonScore>
				</xsl:if>
				<xsl:copy-of select="aqua:fields($ref_fields,('AnlassGleasonScore_xxx_VERLAUF', 'DatumStanzen_xxx_VERLAUF', 'AnzahlStanzen_xxx_VERLAUF', 'AnzahlPosStanzen_xxx_VERLAUF'))"/>
				<xsl:variable name="ca_befall_prozent">
					<xsl:copy-of select="aqua:fields($ref_fields,('Prozentzahl_xxx_VERLAUF'))"/>
				</xsl:variable>
				<xsl:variable name="ca_befall_unbekannt">
					<xsl:copy-of select="aqua:fields($ref_fields,('U_xxx_VERLAUF'))"/>
				</xsl:variable>
				<xsl:if test="$ca_befall_prozent/* or $ca_befall_unbekannt/*">
					<CaBefallStanze>
						<xsl:choose>
							<xsl:when test="$ca_befall_prozent/*">
								<xsl:copy-of select="$ca_befall_prozent"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="$ca_befall_unbekannt"/>
							</xsl:otherwise>
						</xsl:choose>
					</CaBefallStanze>
				</xsl:if>
				<xsl:copy-of select="aqua:fields($ref_fields,('PSA_xxx_VERLAUF', 'DatumPSA_xxx_VERLAUF', 'KomplPostOP_ClavienDindo_xxx_VERLAUF'))"/>
			</xsl:variable>
			<!--Modul Malignes Melanom -->
			<xsl:variable name="modul_malignes_melanom">
				<xsl:copy-of select="aqua:fields($ref_fields,('Sicherheitsabstand_Primaertumor_xxx_VERLAUF', 
					'Tumordicke_xxx_VERLAUF',
					'LDH_xxx_VERLAUF',
					'Ulzeration_xxx_VERLAUF'))"/>
			</xsl:variable>
			<!-- Tod -->
			<xsl:variable name="tod">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Sterbedatum', 'Tod_tumorbedingt'))"/>
				<xsl:variable name="menge_todesursache">
					<xsl:copy-of select="aqua:fields($ref_fields, ('Todesursache_ICD','Todesursache_ICD_Version'))"/>
				</xsl:variable>
				<xsl:if test="$menge_todesursache/*">
					<Menge_Todesursache>
						<xsl:copy-of select="$menge_todesursache"/>
					</Menge_Todesursache>
				</xsl:if>
			</xsl:variable>
			<!-- AUSGABE -->
			<!-- Histologie -->
			<xsl:if test="$hist/*">
				<Histologie>
					<xsl:copy-of select="$hist"/>
				</Histologie>
			</xsl:if>
			<!-- TNM -->
			<xsl:if test="$tnm/*">
				<TNM>
					<xsl:copy-of select="$tnm"/>
				</TNM>
			</xsl:if>
			<!-- Menge weitere Klassifikationen -->
			<xsl:if test="$menge_weitere_klassifikationen/*">
				<Menge_Weitere_Klassifikation>
					<xsl:copy-of select="$menge_weitere_klassifikationen"/>
				</Menge_Weitere_Klassifikation>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Untersuchungsdatum_Verlauf', 
				'Gesamtbeurteilung_Tumorstatus', 
				'Verlauf_Lokaler_Tumorstatus', 
				'Verlauf_Tumorstatus_Lymphknoten', 
				'Verlauf_Tumorstatus_Fernmetastasen'))"/>
			<!-- Menge Fernmetastasen -->
			<xsl:if test="$menge_fernmetastasen/*">
				<Menge_FM>
					<xsl:copy-of select="$menge_fernmetastasen"/>
				</Menge_FM>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Allgemeiner_Leistungszustand_xxx_VERLAUF'))"/>
			<!--Modul Prostatakrebs -->
			<xsl:if test="$modul_prostata/*">
				<Modul_Prostata>
					<xsl:copy-of select="$modul_prostata"/>
				</Modul_Prostata>
			</xsl:if>
			<!--Modul Malignes Melanom -->
			<xsl:if test="$modul_malignes_melanom/*">
				<Modul_Malignes_Melanom>
					<xsl:copy-of select="$modul_malignes_melanom"/>
				</Modul_Malignes_Melanom>
			</xsl:if>
			<!-- Modul Allgemein -->
			<xsl:if test="$modul_allgemein/*">
				<Modul_Allgemein>
					<xsl:copy-of select="$modul_allgemein"/>
				</Modul_Allgemein>
			</xsl:if>
			<!-- Tod -->
			<xsl:if test="$tod/*">
				<Tod>
					<xsl:copy-of select="$tod"/>
				</Tod>
			</xsl:if>
			<xsl:copy-of select="aqua:fields($ref_fields, ('Anmerkung_xxx_VERLAUF'))"/>
		</Verlauf>
	</xsl:template>
	<xsl:template name="tumorkonferenz">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases/felder"/>
		<Tumorkonferenz Tumorkonferenz_ID="{$ref_fields/Tumorkonferenz_ID/@V}">
			<xsl:variable name="tumorkonferenz">
				<xsl:copy-of select="aqua:fields($ref_fields, ('Tumorkonferenz_Datum', 'Tumorkonferenz_Typ', 'Anmerkung_xxx_TUMORKONF'))"/>
			</xsl:variable>
			<xsl:if test="$tumorkonferenz/*">
				<xsl:copy-of select="$tumorkonferenz"/>
			</xsl:if>
		</Tumorkonferenz>
	</xsl:template>
	<xsl:template match="felder" mode="absender">
		<xsl:param name="cases"/>
		<xsl:variable name="ref_fields" select="$cases/provider"/>
		<Absender Absender_ID="{Absender_ID/@V}" Software_ID="{Software_ID/@V}" Installations_ID="{Installations_ID/@V}">
			<Absender_Bezeichnung>
				<xsl:value-of select="$ref_fields/@name"/>
			</Absender_Bezeichnung>
			<Absender_Anschrift>
				<xsl:value-of select="$ref_fields/@address"/>
			</Absender_Anschrift>
			<Absender_Telefon>
				<xsl:value-of select="$ref_fields/@phone"/>
			</Absender_Telefon>
			<Absender_EMail>
				<xsl:value-of select="$ref_fields/@email"/>
			</Absender_EMail>
		</Absender>
	</xsl:template>
	<xsl:template name="melder">
		<!--übernahme der Paramter-Results-->
		<xsl:param name="cases"/>
		<!-- nicht alle cases von derselben ID werden benötigt -->
		<xsl:variable name="ref_fields" select="$cases[1]"/>
		<Melder Melder_ID="{$ref_fields/Melder_ID/@V}">
			<!-- own function -->
			<xsl:copy-of select="aqua:fields($ref_fields, ('Melder_IKNR',
				'Melder_LANR',
				'Melder_BSNR',
				'Meldende_Stelle',
				'Melder_KH_Abt_Station_Praxis',
				'Melder_Arztname',
				'Melder_Anschrift',
				'Melder_PLZ',
				'Melder_Ort', 
				'Melder_Bankname', 
				'Melder_Kontoinhaber', 
				'Melder_BIC', 
				'Melder_IBAN'))"/>
		</Melder>
	</xsl:template>
	<xsl:function name="aqua:fields">
		<xsl:param name="fields"/>
		<xsl:param name="field_names"/>
		<xsl:for-each select="$field_names">
			<xsl:variable name="field_name" select="."/>
			<xsl:apply-templates mode="value" select="$fields/*[local-name() = $field_name]"/>
		</xsl:for-each>
	</xsl:function>
	<xsl:template match="node()" mode="value">
		<xsl:variable name="name" select="local-name(.)"/>
		<xsl:variable name="value" select="@V"/>
		<xsl:variable name="tvalue" select="string($value)"/>
		<xsl:if test="$tvalue != ''">
			<xsl:choose>
				<!-- Workaround für weitere Klassifikation / DIAG -->
				<xsl:when test="$name = 'Name_sonstige_xxx_DIAG'">
					<xsl:element name="Name">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>
				<!-- Workaround für weitere Klassifikation / VERLAUF -->
				<xsl:when test="$name = 'Name_sonstige_xxx_VERLAUF'">
					<xsl:element name="Name">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>
				<!-- Workaround für Einzel- und Gesamtdosis / ST -->
				<xsl:when test="$name = 'ST_Einzeldosis_xxx_ST' or $name = 'ST_Gesamtdosis_xxx_ST'">
					<xsl:element name="Dosis">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>
				<!-- Workaround für Einzel- und Gesamtdosis Einheit / ST -->
				<xsl:when test="$name = 'ST_Einzeldosis_Einheit_xxx_ST' or $name='ST_Gesamtdosis_Einheit_xxx_ST'">
					<xsl:element name="Einheit">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>
				<!-- Workaround für xxx-Felder -->
				<xsl:when test="contains($name,'_xxx_')">
					<xsl:element name="{substring-before($name,'_xxx_')}">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:when>
				<xsl:otherwise>
					<xsl:element name="{$name}">
						<xsl:value-of select="$value"/>
					</xsl:element>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	<xsl:function name="aqua:endate" as="xs:string*">
		<xsl:param name="dedate" as="xs:string"/>
		<xsl:choose>
			<xsl:when test="$dedate castable as xs:date">
				<xsl:value-of select="$dedate"/>
			</xsl:when>
			<xsl:when test="substring($dedate, string-length($dedate)-4) = '-00-00'">
				<xsl:value-of select="$dedate"/>
			</xsl:when>
			<xsl:when test="substring($dedate, string-length($dedate)-2) = '-00'">
				<xsl:value-of select="$dedate"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:analyze-string select="$dedate" regex="(\d{{2}})\.(\d{{2}})\.(\d{{4}})">
					<xsl:matching-substring>
						<xsl:value-of select="concat(regex-group(3),'-',regex-group(2),'-',regex-group(1))"/>
					</xsl:matching-substring>
				</xsl:analyze-string>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:function>
</xsl:stylesheet>
